# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: reports.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='reports.proto',
  package='mdg.engine.proto',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=_b('\n\rreports.proto\x12\x10mdg.engine.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xe9\x19\n\x05Trace\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x13\n\x0b\x64uration_ns\x18\x0b \x01(\x04\x12*\n\x04root\x18\x0e \x01(\x0b\x32\x1c.mdg.engine.proto.Trace.Node\x12\x11\n\tsignature\x18\x13 \x01(\t\x12\x30\n\x07\x64\x65tails\x18\x06 \x01(\x0b\x32\x1f.mdg.engine.proto.Trace.Details\x12\x13\n\x0b\x63lient_name\x18\x07 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x08 \x01(\t\x12\x16\n\x0e\x63lient_address\x18\t \x01(\t\x12\x1b\n\x13\x63lient_reference_id\x18\x17 \x01(\t\x12*\n\x04http\x18\n \x01(\x0b\x32\x1c.mdg.engine.proto.Trace.HTTP\x12\x39\n\x0c\x63\x61\x63he_policy\x18\x12 \x01(\x0b\x32#.mdg.engine.proto.Trace.CachePolicy\x12\x39\n\nquery_plan\x18\x1a \x01(\x0b\x32%.mdg.engine.proto.Trace.QueryPlanNode\x12\x1c\n\x14\x66ull_query_cache_hit\x18\x14 \x01(\x08\x12\x1b\n\x13persisted_query_hit\x18\x15 \x01(\x08\x12 \n\x18persisted_query_register\x18\x16 \x01(\x08\x12\x1c\n\x14registered_operation\x18\x18 \x01(\x08\x12\x1b\n\x13\x66orbidden_operation\x18\x19 \x01(\x08\x12>\n\x1aorigin_reported_start_time\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12<\n\x18origin_reported_end_time\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12#\n\x1borigin_reported_duration_ns\x18\x11 \x01(\x04\x12(\n legacy_signature_needs_resigning\x18\x05 \x01(\t\x1a\x8a\x01\n\x0b\x43\x61\x63hePolicy\x12\x38\n\x05scope\x18\x01 \x01(\x0e\x32).mdg.engine.proto.Trace.CachePolicy.Scope\x12\x12\n\nmax_age_ns\x18\x02 \x01(\x03\"-\n\x05Scope\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\x1a\xab\x02\n\x07\x44\x65tails\x12J\n\x0evariables_json\x18\x04 \x03(\x0b\x32\x32.mdg.engine.proto.Trace.Details.VariablesJsonEntry\x12\x41\n\tvariables\x18\x01 \x03(\x0b\x32..mdg.engine.proto.Trace.Details.VariablesEntry\x12\x11\n\traw_query\x18\x02 \x01(\t\x12\x16\n\x0eoperation_name\x18\x03 \x01(\t\x1a\x34\n\x12VariablesJsonEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x30\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x0c:\x02\x38\x01\x1ak\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x32\n\x08location\x18\x02 \x03(\x0b\x32 .mdg.engine.proto.Trace.Location\x12\x0f\n\x07time_ns\x18\x03 \x01(\x04\x12\x0c\n\x04json\x18\x04 \x01(\t\x1a\xf1\x04\n\x04HTTP\x12\x33\n\x06method\x18\x01 \x01(\x0e\x32#.mdg.engine.proto.Trace.HTTP.Method\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\x0c\n\x04path\x18\x03 \x01(\t\x12I\n\x0frequest_headers\x18\x04 \x03(\x0b\x32\x30.mdg.engine.proto.Trace.HTTP.RequestHeadersEntry\x12K\n\x10response_headers\x18\x05 \x03(\x0b\x32\x31.mdg.engine.proto.Trace.HTTP.ResponseHeadersEntry\x12\x13\n\x0bstatus_code\x18\x06 \x01(\r\x12\x0e\n\x06secure\x18\x08 \x01(\x08\x12\x10\n\x08protocol\x18\t \x01(\t\x1a\x17\n\x06Values\x12\r\n\x05value\x18\x01 \x03(\t\x1aZ\n\x13RequestHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.mdg.engine.proto.Trace.HTTP.Values:\x02\x38\x01\x1a[\n\x14ResponseHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x32\n\x05value\x18\x02 \x01(\x0b\x32#.mdg.engine.proto.Trace.HTTP.Values:\x02\x38\x01\"w\n\x06Method\x12\x0b\n\x07UNKNOWN\x10\x00\x12\x0b\n\x07OPTIONS\x10\x01\x12\x07\n\x03GET\x10\x02\x12\x08\n\x04HEAD\x10\x03\x12\x08\n\x04POST\x10\x04\x12\x07\n\x03PUT\x10\x05\x12\n\n\x06\x44\x45LETE\x10\x06\x12\t\n\x05TRACE\x10\x07\x12\x0b\n\x07\x43ONNECT\x10\x08\x12\t\n\x05PATCH\x10\t\x1a(\n\x08Location\x12\x0c\n\x04line\x18\x01 \x01(\r\x12\x0e\n\x06\x63olumn\x18\x02 \x01(\r\x1a\xb8\x02\n\x04Node\x12\x17\n\rresponse_name\x18\x01 \x01(\tH\x00\x12\x0f\n\x05index\x18\x02 \x01(\rH\x00\x12\x1b\n\x13original_field_name\x18\x0e \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x13\n\x0bparent_type\x18\r \x01(\t\x12\x39\n\x0c\x63\x61\x63he_policy\x18\x05 \x01(\x0b\x32#.mdg.engine.proto.Trace.CachePolicy\x12\x12\n\nstart_time\x18\x08 \x01(\x04\x12\x10\n\x08\x65nd_time\x18\t \x01(\x04\x12,\n\x05\x65rror\x18\x0b \x03(\x0b\x32\x1d.mdg.engine.proto.Trace.Error\x12+\n\x05\x63hild\x18\x0c \x03(\x0b\x32\x1c.mdg.engine.proto.Trace.NodeB\x04\n\x02idJ\x04\x08\x04\x10\x05\x1a\xf9\x06\n\rQueryPlanNode\x12\x46\n\x08sequence\x18\x01 \x01(\x0b\x32\x32.mdg.engine.proto.Trace.QueryPlanNode.SequenceNodeH\x00\x12\x46\n\x08parallel\x18\x02 \x01(\x0b\x32\x32.mdg.engine.proto.Trace.QueryPlanNode.ParallelNodeH\x00\x12@\n\x05\x66\x65tch\x18\x03 \x01(\x0b\x32/.mdg.engine.proto.Trace.QueryPlanNode.FetchNodeH\x00\x12\x44\n\x07\x66latten\x18\x04 \x01(\x0b\x32\x31.mdg.engine.proto.Trace.QueryPlanNode.FlattenNodeH\x00\x1a\x44\n\x0cSequenceNode\x12\x34\n\x05nodes\x18\x01 \x03(\x0b\x32%.mdg.engine.proto.Trace.QueryPlanNode\x1a\x44\n\x0cParallelNode\x12\x34\n\x05nodes\x18\x01 \x03(\x0b\x32%.mdg.engine.proto.Trace.QueryPlanNode\x1a\xe0\x01\n\tFetchNode\x12\x13\n\x0bserviceName\x18\x01 \x01(\t\x12\x1a\n\x12traceParsingFailed\x18\x02 \x01(\x08\x12&\n\x05trace\x18\x03 \x01(\x0b\x32\x17.mdg.engine.proto.Trace\x12\x18\n\x10sent_time_offset\x18\x04 \x01(\x04\x12-\n\tsent_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rreceived_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x1a\x94\x01\n\x0b\x46lattenNode\x12P\n\rresponse_path\x18\x01 \x03(\x0b\x32\x39.mdg.engine.proto.Trace.QueryPlanNode.ResponsePathElement\x12\x33\n\x04node\x18\x02 \x01(\x0b\x32%.mdg.engine.proto.Trace.QueryPlanNode\x1a\x42\n\x13ResponsePathElement\x12\x14\n\nfield_name\x18\x01 \x01(\tH\x00\x12\x0f\n\x05index\x18\x02 \x01(\rH\x00\x42\x04\n\x02idB\x06\n\x04nodeJ\x04\x08\x0c\x10\rJ\x04\x08\r\x10\x0eJ\x04\x08\x01\x10\x02J\x04\x08\x02\x10\x03\"\xb2\x01\n\x0cReportHeader\x12\x0f\n\x07service\x18\x03 \x01(\t\x12\x10\n\x08hostname\x18\x05 \x01(\t\x12\x15\n\ragent_version\x18\x06 \x01(\t\x12\x17\n\x0fservice_version\x18\x07 \x01(\t\x12\x17\n\x0fruntime_version\x18\x08 \x01(\t\x12\r\n\x05uname\x18\t \x01(\t\x12\x12\n\nschema_tag\x18\n \x01(\t\x12\x13\n\x0bschema_hash\x18\x0b \x01(\t\"\xdf\x01\n\x0ePathErrorStats\x12@\n\x08\x63hildren\x18\x01 \x03(\x0b\x32..mdg.engine.proto.PathErrorStats.ChildrenEntry\x12\x14\n\x0c\x65rrors_count\x18\x04 \x01(\x04\x12\"\n\x1arequests_with_errors_count\x18\x05 \x01(\x04\x1aQ\n\rChildrenEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12/\n\x05value\x18\x02 \x01(\x0b\x32 .mdg.engine.proto.PathErrorStats:\x02\x38\x01\"\x9f\n\n\x0f\x43lientNameStats\x12\x15\n\rlatency_count\x18\x01 \x03(\x03\x12\x62\n\x1arequests_count_per_version\x18\x03 \x03(\x0b\x32>.mdg.engine.proto.ClientNameStats.RequestsCountPerVersionEntry\x12Z\n\x16\x63\x61\x63he_hits_per_version\x18\x04 \x03(\x0b\x32:.mdg.engine.proto.ClientNameStats.CacheHitsPerVersionEntry\x12m\n persisted_query_hits_per_version\x18\n \x03(\x0b\x32\x43.mdg.engine.proto.ClientNameStats.PersistedQueryHitsPerVersionEntry\x12q\n\"persisted_query_misses_per_version\x18\x0b \x03(\x0b\x32\x45.mdg.engine.proto.ClientNameStats.PersistedQueryMissesPerVersionEntry\x12y\n&registered_operation_count_per_version\x18\x0c \x03(\x0b\x32I.mdg.engine.proto.ClientNameStats.RegisteredOperationCountPerVersionEntry\x12w\n%forbidden_operation_count_per_version\x18\r \x03(\x0b\x32H.mdg.engine.proto.ClientNameStats.ForbiddenOperationCountPerVersionEntry\x12\x1b\n\x13\x63\x61\x63he_latency_count\x18\x05 \x03(\x03\x12:\n\x10root_error_stats\x18\x06 \x01(\x0b\x32 .mdg.engine.proto.PathErrorStats\x12\"\n\x1arequests_with_errors_count\x18\x07 \x01(\x04\x12\x1e\n\x16public_cache_ttl_count\x18\x08 \x03(\x03\x12\x1f\n\x17private_cache_ttl_count\x18\t \x03(\x03\x1a>\n\x1cRequestsCountPerVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a:\n\x18\x43\x61\x63heHitsPerVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x43\n!PersistedQueryHitsPerVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1a\x45\n#PersistedQueryMissesPerVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1aI\n\'RegisteredOperationCountPerVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01\x1aH\n&ForbiddenOperationCountPerVersionEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\x04:\x02\x38\x01J\x04\x08\x02\x10\x03\"\x98\x03\n\x11QueryLatencyStats\x12\x15\n\rlatency_count\x18\x01 \x03(\x03\x12\x15\n\rrequest_count\x18\x02 \x01(\x04\x12\x12\n\ncache_hits\x18\x03 \x01(\x04\x12\x1c\n\x14persisted_query_hits\x18\x04 \x01(\x04\x12\x1e\n\x16persisted_query_misses\x18\x05 \x01(\x04\x12\x1b\n\x13\x63\x61\x63he_latency_count\x18\x06 \x03(\x03\x12:\n\x10root_error_stats\x18\x07 \x01(\x0b\x32 .mdg.engine.proto.PathErrorStats\x12\"\n\x1arequests_with_errors_count\x18\x08 \x01(\x04\x12\x1e\n\x16public_cache_ttl_count\x18\t \x03(\x03\x12\x1f\n\x17private_cache_ttl_count\x18\n \x03(\x03\x12\"\n\x1aregistered_operation_count\x18\x0b \x01(\x04\x12!\n\x19\x66orbidden_operation_count\x18\x0c \x01(\x04\"X\n\x0cStatsContext\x12\x1b\n\x13\x63lient_reference_id\x18\x01 \x01(\t\x12\x13\n\x0b\x63lient_name\x18\x02 \x01(\t\x12\x16\n\x0e\x63lient_version\x18\x03 \x01(\t\"\x94\x01\n\x1f\x43ontextualizedQueryLatencyStats\x12@\n\x13query_latency_stats\x18\x01 \x01(\x0b\x32#.mdg.engine.proto.QueryLatencyStats\x12/\n\x07\x63ontext\x18\x02 \x01(\x0b\x32\x1e.mdg.engine.proto.StatsContext\"\xed\x01\n\x17\x43ontextualizedTypeStats\x12/\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x1e.mdg.engine.proto.StatsContext\x12Q\n\rper_type_stat\x18\x02 \x03(\x0b\x32:.mdg.engine.proto.ContextualizedTypeStats.PerTypeStatEntry\x1aN\n\x10PerTypeStatEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.mdg.engine.proto.TypeStat:\x02\x38\x01\"\x8e\x01\n\tFieldStat\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0breturn_type\x18\x03 \x01(\t\x12\x14\n\x0c\x65rrors_count\x18\x04 \x01(\x04\x12\r\n\x05\x63ount\x18\x05 \x01(\x04\x12\"\n\x1arequests_with_errors_count\x18\x06 \x01(\x04\x12\x15\n\rlatency_count\x18\x08 \x03(\x03\"\xdc\x01\n\x08TypeStat\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\x05\x66ield\x18\x02 \x03(\x0b\x32\x1b.mdg.engine.proto.FieldStat\x12\x44\n\x0eper_field_stat\x18\x03 \x03(\x0b\x32,.mdg.engine.proto.TypeStat.PerFieldStatEntry\x1aP\n\x11PerFieldStatEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12*\n\x05value\x18\x02 \x01(\x0b\x32\x1b.mdg.engine.proto.FieldStat:\x02\x38\x01\"\x94\x04\n\nQueryStats\x12H\n\x0fper_client_name\x18\x01 \x03(\x0b\x32/.mdg.engine.proto.QueryStats.PerClientNameEntry\x12S\n\x18query_stats_with_context\x18\x04 \x03(\x0b\x32\x31.mdg.engine.proto.ContextualizedQueryLatencyStats\x12,\n\x08per_type\x18\x02 \x03(\x0b\x32\x1a.mdg.engine.proto.TypeStat\x12\x44\n\rper_type_stat\x18\x03 \x03(\x0b\x32-.mdg.engine.proto.QueryStats.PerTypeStatEntry\x12J\n\x17type_stats_with_context\x18\x05 \x03(\x0b\x32).mdg.engine.proto.ContextualizedTypeStats\x1aW\n\x12PerClientNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x30\n\x05value\x18\x02 \x01(\x0b\x32!.mdg.engine.proto.ClientNameStats:\x02\x38\x01\x1aN\n\x10PerTypeStatEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.mdg.engine.proto.TypeStat:\x02\x38\x01\"f\n\x0cTracesReport\x12.\n\x06header\x18\x01 \x01(\x0b\x32\x1e.mdg.engine.proto.ReportHeader\x12&\n\x05trace\x18\x02 \x03(\x0b\x32\x17.mdg.engine.proto.Trace\"*\n\x05\x46ield\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0breturn_type\x18\x03 \x01(\t\"<\n\x04Type\x12\x0c\n\x04name\x18\x01 \x01(\t\x12&\n\x05\x66ield\x18\x02 \x03(\x0b\x32\x17.mdg.engine.proto.Field\"\xf5\x02\n\x08MemStats\x12\x13\n\x0btotal_bytes\x18\x01 \x01(\x04\x12\x13\n\x0bstack_bytes\x18\x02 \x01(\x04\x12\x12\n\nheap_bytes\x18\x03 \x01(\x04\x12\x1b\n\x13heap_released_bytes\x18\r \x01(\x04\x12\x19\n\x11gc_overhead_bytes\x18\x04 \x01(\x04\x12\x18\n\x10stack_used_bytes\x18\x05 \x01(\x04\x12\x1c\n\x14heap_allocated_bytes\x18\x06 \x01(\x04\x12\x1e\n\x16heap_allocated_objects\x18\x07 \x01(\x04\x12\"\n\x1aheap_allocated_bytes_delta\x18\x08 \x01(\x04\x12$\n\x1cheap_allocated_objects_delta\x18\t \x01(\x04\x12 \n\x18heap_freed_objects_delta\x18\n \x01(\x04\x12\x17\n\x0fgc_stw_ns_delta\x18\x0b \x01(\x04\x12\x16\n\x0egc_count_delta\x18\x0c \x01(\x04\"b\n\tTimeStats\x12\x11\n\tuptime_ns\x18\x01 \x01(\x04\x12\x15\n\rreal_ns_delta\x18\x02 \x01(\x04\x12\x15\n\ruser_ns_delta\x18\x03 \x01(\x04\x12\x14\n\x0csys_ns_delta\x18\x04 \x01(\x04\"\xaf\x05\n\x0bStatsReport\x12.\n\x06header\x18\x01 \x01(\x0b\x32\x1e.mdg.engine.proto.ReportHeader\x12-\n\tmem_stats\x18\x02 \x01(\x0b\x32\x1a.mdg.engine.proto.MemStats\x12/\n\ntime_stats\x18\x03 \x01(\x0b\x32\x1b.mdg.engine.proto.TimeStats\x12.\n\nstart_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x19\n\x11realtime_duration\x18\n \x01(\x04\x12>\n\tper_query\x18\x0e \x03(\x0b\x32+.mdg.engine.proto.StatsReport.PerQueryEntry\x12x\n(legacy_per_query_implicit_operation_name\x18\x0c \x03(\x0b\x32\x46.mdg.engine.proto.StatsReport.LegacyPerQueryImplicitOperationNameEntry\x12$\n\x04type\x18\r \x03(\x0b\x32\x16.mdg.engine.proto.Type\x1aM\n\rPerQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.mdg.engine.proto.QueryStats:\x02\x38\x01\x1ah\n(LegacyPerQueryImplicitOperationNameEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12+\n\x05value\x18\x02 \x01(\x0b\x32\x1c.mdg.engine.proto.QueryStats:\x02\x38\x01\"\xe5\x01\n\x10\x46ullTracesReport\x12.\n\x06header\x18\x01 \x01(\x0b\x32\x1e.mdg.engine.proto.ReportHeader\x12P\n\x10traces_per_query\x18\x05 \x03(\x0b\x32\x36.mdg.engine.proto.FullTracesReport.TracesPerQueryEntry\x1aO\n\x13TracesPerQueryEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\'\n\x05value\x18\x02 \x01(\x0b\x32\x18.mdg.engine.proto.Traces:\x02\x38\x01\"0\n\x06Traces\x12&\n\x05trace\x18\x01 \x03(\x0b\x32\x17.mdg.engine.proto.Trace\"a\n\x07TraceV1\x12.\n\x06header\x18\x01 \x01(\x0b\x32\x1e.mdg.engine.proto.ReportHeader\x12&\n\x05trace\x18\x02 \x01(\x0b\x32\x17.mdg.engine.proto.Traceb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_TRACE_CACHEPOLICY_SCOPE = _descriptor.EnumDescriptor(
  name='Scope',
  full_name='mdg.engine.proto.Trace.CachePolicy.Scope',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUBLIC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PRIVATE', index=2, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1017,
  serialized_end=1062,
)
_sym_db.RegisterEnumDescriptor(_TRACE_CACHEPOLICY_SCOPE)

_TRACE_HTTP_METHOD = _descriptor.EnumDescriptor(
  name='Method',
  full_name='mdg.engine.proto.Trace.HTTP.Method',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OPTIONS', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='GET', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='HEAD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='POST', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PUT', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DELETE', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TRACE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CONNECT', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PATCH', index=9, number=9,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1982,
  serialized_end=2101,
)
_sym_db.RegisterEnumDescriptor(_TRACE_HTTP_METHOD)


_TRACE_CACHEPOLICY = _descriptor.Descriptor(
  name='CachePolicy',
  full_name='mdg.engine.proto.Trace.CachePolicy',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='scope', full_name='mdg.engine.proto.Trace.CachePolicy.scope', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='max_age_ns', full_name='mdg.engine.proto.Trace.CachePolicy.max_age_ns', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _TRACE_CACHEPOLICY_SCOPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=1062,
)

_TRACE_DETAILS_VARIABLESJSONENTRY = _descriptor.Descriptor(
  name='VariablesJsonEntry',
  full_name='mdg.engine.proto.Trace.Details.VariablesJsonEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.Trace.Details.VariablesJsonEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.Trace.Details.VariablesJsonEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1262,
  serialized_end=1314,
)

_TRACE_DETAILS_VARIABLESENTRY = _descriptor.Descriptor(
  name='VariablesEntry',
  full_name='mdg.engine.proto.Trace.Details.VariablesEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.Trace.Details.VariablesEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.Trace.Details.VariablesEntry.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1316,
  serialized_end=1364,
)

_TRACE_DETAILS = _descriptor.Descriptor(
  name='Details',
  full_name='mdg.engine.proto.Trace.Details',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variables_json', full_name='mdg.engine.proto.Trace.Details.variables_json', index=0,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='variables', full_name='mdg.engine.proto.Trace.Details.variables', index=1,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='raw_query', full_name='mdg.engine.proto.Trace.Details.raw_query', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operation_name', full_name='mdg.engine.proto.Trace.Details.operation_name', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRACE_DETAILS_VARIABLESJSONENTRY, _TRACE_DETAILS_VARIABLESENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1065,
  serialized_end=1364,
)

_TRACE_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='mdg.engine.proto.Trace.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='mdg.engine.proto.Trace.Error.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='location', full_name='mdg.engine.proto.Trace.Error.location', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_ns', full_name='mdg.engine.proto.Trace.Error.time_ns', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='json', full_name='mdg.engine.proto.Trace.Error.json', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1366,
  serialized_end=1473,
)

_TRACE_HTTP_VALUES = _descriptor.Descriptor(
  name='Values',
  full_name='mdg.engine.proto.Trace.HTTP.Values',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.Trace.HTTP.Values.value', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1772,
  serialized_end=1795,
)

_TRACE_HTTP_REQUESTHEADERSENTRY = _descriptor.Descriptor(
  name='RequestHeadersEntry',
  full_name='mdg.engine.proto.Trace.HTTP.RequestHeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.Trace.HTTP.RequestHeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.Trace.HTTP.RequestHeadersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1797,
  serialized_end=1887,
)

_TRACE_HTTP_RESPONSEHEADERSENTRY = _descriptor.Descriptor(
  name='ResponseHeadersEntry',
  full_name='mdg.engine.proto.Trace.HTTP.ResponseHeadersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.Trace.HTTP.ResponseHeadersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.Trace.HTTP.ResponseHeadersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1889,
  serialized_end=1980,
)

_TRACE_HTTP = _descriptor.Descriptor(
  name='HTTP',
  full_name='mdg.engine.proto.Trace.HTTP',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='method', full_name='mdg.engine.proto.Trace.HTTP.method', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='host', full_name='mdg.engine.proto.Trace.HTTP.host', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='path', full_name='mdg.engine.proto.Trace.HTTP.path', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_headers', full_name='mdg.engine.proto.Trace.HTTP.request_headers', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='response_headers', full_name='mdg.engine.proto.Trace.HTTP.response_headers', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status_code', full_name='mdg.engine.proto.Trace.HTTP.status_code', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secure', full_name='mdg.engine.proto.Trace.HTTP.secure', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protocol', full_name='mdg.engine.proto.Trace.HTTP.protocol', index=7,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRACE_HTTP_VALUES, _TRACE_HTTP_REQUESTHEADERSENTRY, _TRACE_HTTP_RESPONSEHEADERSENTRY, ],
  enum_types=[
    _TRACE_HTTP_METHOD,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1476,
  serialized_end=2101,
)

_TRACE_LOCATION = _descriptor.Descriptor(
  name='Location',
  full_name='mdg.engine.proto.Trace.Location',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='line', full_name='mdg.engine.proto.Trace.Location.line', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='mdg.engine.proto.Trace.Location.column', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2103,
  serialized_end=2143,
)

_TRACE_NODE = _descriptor.Descriptor(
  name='Node',
  full_name='mdg.engine.proto.Trace.Node',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_name', full_name='mdg.engine.proto.Trace.Node.response_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='mdg.engine.proto.Trace.Node.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='original_field_name', full_name='mdg.engine.proto.Trace.Node.original_field_name', index=2,
      number=14, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='mdg.engine.proto.Trace.Node.type', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent_type', full_name='mdg.engine.proto.Trace.Node.parent_type', index=4,
      number=13, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_policy', full_name='mdg.engine.proto.Trace.Node.cache_policy', index=5,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='mdg.engine.proto.Trace.Node.start_time', index=6,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='mdg.engine.proto.Trace.Node.end_time', index=7,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error', full_name='mdg.engine.proto.Trace.Node.error', index=8,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='child', full_name='mdg.engine.proto.Trace.Node.child', index=9,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='mdg.engine.proto.Trace.Node.id',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2146,
  serialized_end=2458,
)

_TRACE_QUERYPLANNODE_SEQUENCENODE = _descriptor.Descriptor(
  name='SequenceNode',
  full_name='mdg.engine.proto.Trace.QueryPlanNode.SequenceNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='mdg.engine.proto.Trace.QueryPlanNode.SequenceNode.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2758,
  serialized_end=2826,
)

_TRACE_QUERYPLANNODE_PARALLELNODE = _descriptor.Descriptor(
  name='ParallelNode',
  full_name='mdg.engine.proto.Trace.QueryPlanNode.ParallelNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nodes', full_name='mdg.engine.proto.Trace.QueryPlanNode.ParallelNode.nodes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2828,
  serialized_end=2896,
)

_TRACE_QUERYPLANNODE_FETCHNODE = _descriptor.Descriptor(
  name='FetchNode',
  full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode.serviceName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traceParsingFailed', full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode.traceParsingFailed', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode.trace', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sent_time_offset', full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode.sent_time_offset', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sent_time', full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode.sent_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='received_time', full_name='mdg.engine.proto.Trace.QueryPlanNode.FetchNode.received_time', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2899,
  serialized_end=3123,
)

_TRACE_QUERYPLANNODE_FLATTENNODE = _descriptor.Descriptor(
  name='FlattenNode',
  full_name='mdg.engine.proto.Trace.QueryPlanNode.FlattenNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response_path', full_name='mdg.engine.proto.Trace.QueryPlanNode.FlattenNode.response_path', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node', full_name='mdg.engine.proto.Trace.QueryPlanNode.FlattenNode.node', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3126,
  serialized_end=3274,
)

_TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT = _descriptor.Descriptor(
  name='ResponsePathElement',
  full_name='mdg.engine.proto.Trace.QueryPlanNode.ResponsePathElement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='field_name', full_name='mdg.engine.proto.Trace.QueryPlanNode.ResponsePathElement.field_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='index', full_name='mdg.engine.proto.Trace.QueryPlanNode.ResponsePathElement.index', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='id', full_name='mdg.engine.proto.Trace.QueryPlanNode.ResponsePathElement.id',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=3276,
  serialized_end=3342,
)

_TRACE_QUERYPLANNODE = _descriptor.Descriptor(
  name='QueryPlanNode',
  full_name='mdg.engine.proto.Trace.QueryPlanNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequence', full_name='mdg.engine.proto.Trace.QueryPlanNode.sequence', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parallel', full_name='mdg.engine.proto.Trace.QueryPlanNode.parallel', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fetch', full_name='mdg.engine.proto.Trace.QueryPlanNode.fetch', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='flatten', full_name='mdg.engine.proto.Trace.QueryPlanNode.flatten', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRACE_QUERYPLANNODE_SEQUENCENODE, _TRACE_QUERYPLANNODE_PARALLELNODE, _TRACE_QUERYPLANNODE_FETCHNODE, _TRACE_QUERYPLANNODE_FLATTENNODE, _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='node', full_name='mdg.engine.proto.Trace.QueryPlanNode.node',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2461,
  serialized_end=3350,
)

_TRACE = _descriptor.Descriptor(
  name='Trace',
  full_name='mdg.engine.proto.Trace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start_time', full_name='mdg.engine.proto.Trace.start_time', index=0,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='mdg.engine.proto.Trace.end_time', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='duration_ns', full_name='mdg.engine.proto.Trace.duration_ns', index=2,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root', full_name='mdg.engine.proto.Trace.root', index=3,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='mdg.engine.proto.Trace.signature', index=4,
      number=19, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='details', full_name='mdg.engine.proto.Trace.details', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_name', full_name='mdg.engine.proto.Trace.client_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='mdg.engine.proto.Trace.client_version', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_address', full_name='mdg.engine.proto.Trace.client_address', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_reference_id', full_name='mdg.engine.proto.Trace.client_reference_id', index=9,
      number=23, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='http', full_name='mdg.engine.proto.Trace.http', index=10,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_policy', full_name='mdg.engine.proto.Trace.cache_policy', index=11,
      number=18, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_plan', full_name='mdg.engine.proto.Trace.query_plan', index=12,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='full_query_cache_hit', full_name='mdg.engine.proto.Trace.full_query_cache_hit', index=13,
      number=20, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persisted_query_hit', full_name='mdg.engine.proto.Trace.persisted_query_hit', index=14,
      number=21, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persisted_query_register', full_name='mdg.engine.proto.Trace.persisted_query_register', index=15,
      number=22, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registered_operation', full_name='mdg.engine.proto.Trace.registered_operation', index=16,
      number=24, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forbidden_operation', full_name='mdg.engine.proto.Trace.forbidden_operation', index=17,
      number=25, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_reported_start_time', full_name='mdg.engine.proto.Trace.origin_reported_start_time', index=18,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_reported_end_time', full_name='mdg.engine.proto.Trace.origin_reported_end_time', index=19,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='origin_reported_duration_ns', full_name='mdg.engine.proto.Trace.origin_reported_duration_ns', index=20,
      number=17, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_signature_needs_resigning', full_name='mdg.engine.proto.Trace.legacy_signature_needs_resigning', index=21,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRACE_CACHEPOLICY, _TRACE_DETAILS, _TRACE_ERROR, _TRACE_HTTP, _TRACE_LOCATION, _TRACE_NODE, _TRACE_QUERYPLANNODE, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=69,
  serialized_end=3374,
)


_REPORTHEADER = _descriptor.Descriptor(
  name='ReportHeader',
  full_name='mdg.engine.proto.ReportHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='mdg.engine.proto.ReportHeader.service', index=0,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='hostname', full_name='mdg.engine.proto.ReportHeader.hostname', index=1,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='agent_version', full_name='mdg.engine.proto.ReportHeader.agent_version', index=2,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service_version', full_name='mdg.engine.proto.ReportHeader.service_version', index=3,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='runtime_version', full_name='mdg.engine.proto.ReportHeader.runtime_version', index=4,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uname', full_name='mdg.engine.proto.ReportHeader.uname', index=5,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema_tag', full_name='mdg.engine.proto.ReportHeader.schema_tag', index=6,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='schema_hash', full_name='mdg.engine.proto.ReportHeader.schema_hash', index=7,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3377,
  serialized_end=3555,
)


_PATHERRORSTATS_CHILDRENENTRY = _descriptor.Descriptor(
  name='ChildrenEntry',
  full_name='mdg.engine.proto.PathErrorStats.ChildrenEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.PathErrorStats.ChildrenEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.PathErrorStats.ChildrenEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3700,
  serialized_end=3781,
)

_PATHERRORSTATS = _descriptor.Descriptor(
  name='PathErrorStats',
  full_name='mdg.engine.proto.PathErrorStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='children', full_name='mdg.engine.proto.PathErrorStats.children', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors_count', full_name='mdg.engine.proto.PathErrorStats.errors_count', index=1,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requests_with_errors_count', full_name='mdg.engine.proto.PathErrorStats.requests_with_errors_count', index=2,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_PATHERRORSTATS_CHILDRENENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3558,
  serialized_end=3781,
)


_CLIENTNAMESTATS_REQUESTSCOUNTPERVERSIONENTRY = _descriptor.Descriptor(
  name='RequestsCountPerVersionEntry',
  full_name='mdg.engine.proto.ClientNameStats.RequestsCountPerVersionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ClientNameStats.RequestsCountPerVersionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ClientNameStats.RequestsCountPerVersionEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4678,
  serialized_end=4740,
)

_CLIENTNAMESTATS_CACHEHITSPERVERSIONENTRY = _descriptor.Descriptor(
  name='CacheHitsPerVersionEntry',
  full_name='mdg.engine.proto.ClientNameStats.CacheHitsPerVersionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ClientNameStats.CacheHitsPerVersionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ClientNameStats.CacheHitsPerVersionEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4742,
  serialized_end=4800,
)

_CLIENTNAMESTATS_PERSISTEDQUERYHITSPERVERSIONENTRY = _descriptor.Descriptor(
  name='PersistedQueryHitsPerVersionEntry',
  full_name='mdg.engine.proto.ClientNameStats.PersistedQueryHitsPerVersionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ClientNameStats.PersistedQueryHitsPerVersionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ClientNameStats.PersistedQueryHitsPerVersionEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4802,
  serialized_end=4869,
)

_CLIENTNAMESTATS_PERSISTEDQUERYMISSESPERVERSIONENTRY = _descriptor.Descriptor(
  name='PersistedQueryMissesPerVersionEntry',
  full_name='mdg.engine.proto.ClientNameStats.PersistedQueryMissesPerVersionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ClientNameStats.PersistedQueryMissesPerVersionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ClientNameStats.PersistedQueryMissesPerVersionEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4871,
  serialized_end=4940,
)

_CLIENTNAMESTATS_REGISTEREDOPERATIONCOUNTPERVERSIONENTRY = _descriptor.Descriptor(
  name='RegisteredOperationCountPerVersionEntry',
  full_name='mdg.engine.proto.ClientNameStats.RegisteredOperationCountPerVersionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ClientNameStats.RegisteredOperationCountPerVersionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ClientNameStats.RegisteredOperationCountPerVersionEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4942,
  serialized_end=5015,
)

_CLIENTNAMESTATS_FORBIDDENOPERATIONCOUNTPERVERSIONENTRY = _descriptor.Descriptor(
  name='ForbiddenOperationCountPerVersionEntry',
  full_name='mdg.engine.proto.ClientNameStats.ForbiddenOperationCountPerVersionEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ClientNameStats.ForbiddenOperationCountPerVersionEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ClientNameStats.ForbiddenOperationCountPerVersionEntry.value', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5017,
  serialized_end=5089,
)

_CLIENTNAMESTATS = _descriptor.Descriptor(
  name='ClientNameStats',
  full_name='mdg.engine.proto.ClientNameStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latency_count', full_name='mdg.engine.proto.ClientNameStats.latency_count', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requests_count_per_version', full_name='mdg.engine.proto.ClientNameStats.requests_count_per_version', index=1,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_hits_per_version', full_name='mdg.engine.proto.ClientNameStats.cache_hits_per_version', index=2,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persisted_query_hits_per_version', full_name='mdg.engine.proto.ClientNameStats.persisted_query_hits_per_version', index=3,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persisted_query_misses_per_version', full_name='mdg.engine.proto.ClientNameStats.persisted_query_misses_per_version', index=4,
      number=11, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registered_operation_count_per_version', full_name='mdg.engine.proto.ClientNameStats.registered_operation_count_per_version', index=5,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forbidden_operation_count_per_version', full_name='mdg.engine.proto.ClientNameStats.forbidden_operation_count_per_version', index=6,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_latency_count', full_name='mdg.engine.proto.ClientNameStats.cache_latency_count', index=7,
      number=5, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_error_stats', full_name='mdg.engine.proto.ClientNameStats.root_error_stats', index=8,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requests_with_errors_count', full_name='mdg.engine.proto.ClientNameStats.requests_with_errors_count', index=9,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_cache_ttl_count', full_name='mdg.engine.proto.ClientNameStats.public_cache_ttl_count', index=10,
      number=8, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_cache_ttl_count', full_name='mdg.engine.proto.ClientNameStats.private_cache_ttl_count', index=11,
      number=9, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTNAMESTATS_REQUESTSCOUNTPERVERSIONENTRY, _CLIENTNAMESTATS_CACHEHITSPERVERSIONENTRY, _CLIENTNAMESTATS_PERSISTEDQUERYHITSPERVERSIONENTRY, _CLIENTNAMESTATS_PERSISTEDQUERYMISSESPERVERSIONENTRY, _CLIENTNAMESTATS_REGISTEREDOPERATIONCOUNTPERVERSIONENTRY, _CLIENTNAMESTATS_FORBIDDENOPERATIONCOUNTPERVERSIONENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3784,
  serialized_end=5095,
)


_QUERYLATENCYSTATS = _descriptor.Descriptor(
  name='QueryLatencyStats',
  full_name='mdg.engine.proto.QueryLatencyStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='latency_count', full_name='mdg.engine.proto.QueryLatencyStats.latency_count', index=0,
      number=1, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request_count', full_name='mdg.engine.proto.QueryLatencyStats.request_count', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_hits', full_name='mdg.engine.proto.QueryLatencyStats.cache_hits', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persisted_query_hits', full_name='mdg.engine.proto.QueryLatencyStats.persisted_query_hits', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='persisted_query_misses', full_name='mdg.engine.proto.QueryLatencyStats.persisted_query_misses', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cache_latency_count', full_name='mdg.engine.proto.QueryLatencyStats.cache_latency_count', index=5,
      number=6, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='root_error_stats', full_name='mdg.engine.proto.QueryLatencyStats.root_error_stats', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requests_with_errors_count', full_name='mdg.engine.proto.QueryLatencyStats.requests_with_errors_count', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_cache_ttl_count', full_name='mdg.engine.proto.QueryLatencyStats.public_cache_ttl_count', index=8,
      number=9, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='private_cache_ttl_count', full_name='mdg.engine.proto.QueryLatencyStats.private_cache_ttl_count', index=9,
      number=10, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='registered_operation_count', full_name='mdg.engine.proto.QueryLatencyStats.registered_operation_count', index=10,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='forbidden_operation_count', full_name='mdg.engine.proto.QueryLatencyStats.forbidden_operation_count', index=11,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5098,
  serialized_end=5506,
)


_STATSCONTEXT = _descriptor.Descriptor(
  name='StatsContext',
  full_name='mdg.engine.proto.StatsContext',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='client_reference_id', full_name='mdg.engine.proto.StatsContext.client_reference_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_name', full_name='mdg.engine.proto.StatsContext.client_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='client_version', full_name='mdg.engine.proto.StatsContext.client_version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5508,
  serialized_end=5596,
)


_CONTEXTUALIZEDQUERYLATENCYSTATS = _descriptor.Descriptor(
  name='ContextualizedQueryLatencyStats',
  full_name='mdg.engine.proto.ContextualizedQueryLatencyStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='query_latency_stats', full_name='mdg.engine.proto.ContextualizedQueryLatencyStats.query_latency_stats', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='context', full_name='mdg.engine.proto.ContextualizedQueryLatencyStats.context', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5599,
  serialized_end=5747,
)


_CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY = _descriptor.Descriptor(
  name='PerTypeStatEntry',
  full_name='mdg.engine.proto.ContextualizedTypeStats.PerTypeStatEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.ContextualizedTypeStats.PerTypeStatEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.ContextualizedTypeStats.PerTypeStatEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5909,
  serialized_end=5987,
)

_CONTEXTUALIZEDTYPESTATS = _descriptor.Descriptor(
  name='ContextualizedTypeStats',
  full_name='mdg.engine.proto.ContextualizedTypeStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='context', full_name='mdg.engine.proto.ContextualizedTypeStats.context', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_type_stat', full_name='mdg.engine.proto.ContextualizedTypeStats.per_type_stat', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5750,
  serialized_end=5987,
)


_FIELDSTAT = _descriptor.Descriptor(
  name='FieldStat',
  full_name='mdg.engine.proto.FieldStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mdg.engine.proto.FieldStat.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='return_type', full_name='mdg.engine.proto.FieldStat.return_type', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errors_count', full_name='mdg.engine.proto.FieldStat.errors_count', index=2,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='count', full_name='mdg.engine.proto.FieldStat.count', index=3,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requests_with_errors_count', full_name='mdg.engine.proto.FieldStat.requests_with_errors_count', index=4,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='latency_count', full_name='mdg.engine.proto.FieldStat.latency_count', index=5,
      number=8, type=3, cpp_type=2, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5990,
  serialized_end=6132,
)


_TYPESTAT_PERFIELDSTATENTRY = _descriptor.Descriptor(
  name='PerFieldStatEntry',
  full_name='mdg.engine.proto.TypeStat.PerFieldStatEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.TypeStat.PerFieldStatEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.TypeStat.PerFieldStatEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6275,
  serialized_end=6355,
)

_TYPESTAT = _descriptor.Descriptor(
  name='TypeStat',
  full_name='mdg.engine.proto.TypeStat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mdg.engine.proto.TypeStat.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='mdg.engine.proto.TypeStat.field', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_field_stat', full_name='mdg.engine.proto.TypeStat.per_field_stat', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TYPESTAT_PERFIELDSTATENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6135,
  serialized_end=6355,
)


_QUERYSTATS_PERCLIENTNAMEENTRY = _descriptor.Descriptor(
  name='PerClientNameEntry',
  full_name='mdg.engine.proto.QueryStats.PerClientNameEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.QueryStats.PerClientNameEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.QueryStats.PerClientNameEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6723,
  serialized_end=6810,
)

_QUERYSTATS_PERTYPESTATENTRY = _descriptor.Descriptor(
  name='PerTypeStatEntry',
  full_name='mdg.engine.proto.QueryStats.PerTypeStatEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.QueryStats.PerTypeStatEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.QueryStats.PerTypeStatEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5909,
  serialized_end=5987,
)

_QUERYSTATS = _descriptor.Descriptor(
  name='QueryStats',
  full_name='mdg.engine.proto.QueryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='per_client_name', full_name='mdg.engine.proto.QueryStats.per_client_name', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='query_stats_with_context', full_name='mdg.engine.proto.QueryStats.query_stats_with_context', index=1,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_type', full_name='mdg.engine.proto.QueryStats.per_type', index=2,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_type_stat', full_name='mdg.engine.proto.QueryStats.per_type_stat', index=3,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type_stats_with_context', full_name='mdg.engine.proto.QueryStats.type_stats_with_context', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_QUERYSTATS_PERCLIENTNAMEENTRY, _QUERYSTATS_PERTYPESTATENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6358,
  serialized_end=6890,
)


_TRACESREPORT = _descriptor.Descriptor(
  name='TracesReport',
  full_name='mdg.engine.proto.TracesReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='mdg.engine.proto.TracesReport.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='mdg.engine.proto.TracesReport.trace', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6892,
  serialized_end=6994,
)


_FIELD = _descriptor.Descriptor(
  name='Field',
  full_name='mdg.engine.proto.Field',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mdg.engine.proto.Field.name', index=0,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='return_type', full_name='mdg.engine.proto.Field.return_type', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6996,
  serialized_end=7038,
)


_TYPE = _descriptor.Descriptor(
  name='Type',
  full_name='mdg.engine.proto.Type',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='mdg.engine.proto.Type.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='field', full_name='mdg.engine.proto.Type.field', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7040,
  serialized_end=7100,
)


_MEMSTATS = _descriptor.Descriptor(
  name='MemStats',
  full_name='mdg.engine.proto.MemStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_bytes', full_name='mdg.engine.proto.MemStats.total_bytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stack_bytes', full_name='mdg.engine.proto.MemStats.stack_bytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_bytes', full_name='mdg.engine.proto.MemStats.heap_bytes', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_released_bytes', full_name='mdg.engine.proto.MemStats.heap_released_bytes', index=3,
      number=13, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gc_overhead_bytes', full_name='mdg.engine.proto.MemStats.gc_overhead_bytes', index=4,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stack_used_bytes', full_name='mdg.engine.proto.MemStats.stack_used_bytes', index=5,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_allocated_bytes', full_name='mdg.engine.proto.MemStats.heap_allocated_bytes', index=6,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_allocated_objects', full_name='mdg.engine.proto.MemStats.heap_allocated_objects', index=7,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_allocated_bytes_delta', full_name='mdg.engine.proto.MemStats.heap_allocated_bytes_delta', index=8,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_allocated_objects_delta', full_name='mdg.engine.proto.MemStats.heap_allocated_objects_delta', index=9,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_freed_objects_delta', full_name='mdg.engine.proto.MemStats.heap_freed_objects_delta', index=10,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gc_stw_ns_delta', full_name='mdg.engine.proto.MemStats.gc_stw_ns_delta', index=11,
      number=11, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gc_count_delta', full_name='mdg.engine.proto.MemStats.gc_count_delta', index=12,
      number=12, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7103,
  serialized_end=7476,
)


_TIMESTATS = _descriptor.Descriptor(
  name='TimeStats',
  full_name='mdg.engine.proto.TimeStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='uptime_ns', full_name='mdg.engine.proto.TimeStats.uptime_ns', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='real_ns_delta', full_name='mdg.engine.proto.TimeStats.real_ns_delta', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user_ns_delta', full_name='mdg.engine.proto.TimeStats.user_ns_delta', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sys_ns_delta', full_name='mdg.engine.proto.TimeStats.sys_ns_delta', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7478,
  serialized_end=7576,
)


_STATSREPORT_PERQUERYENTRY = _descriptor.Descriptor(
  name='PerQueryEntry',
  full_name='mdg.engine.proto.StatsReport.PerQueryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.StatsReport.PerQueryEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.StatsReport.PerQueryEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8083,
  serialized_end=8160,
)

_STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY = _descriptor.Descriptor(
  name='LegacyPerQueryImplicitOperationNameEntry',
  full_name='mdg.engine.proto.StatsReport.LegacyPerQueryImplicitOperationNameEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.StatsReport.LegacyPerQueryImplicitOperationNameEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.StatsReport.LegacyPerQueryImplicitOperationNameEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8162,
  serialized_end=8266,
)

_STATSREPORT = _descriptor.Descriptor(
  name='StatsReport',
  full_name='mdg.engine.proto.StatsReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='mdg.engine.proto.StatsReport.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mem_stats', full_name='mdg.engine.proto.StatsReport.mem_stats', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='time_stats', full_name='mdg.engine.proto.StatsReport.time_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_time', full_name='mdg.engine.proto.StatsReport.start_time', index=3,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_time', full_name='mdg.engine.proto.StatsReport.end_time', index=4,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='realtime_duration', full_name='mdg.engine.proto.StatsReport.realtime_duration', index=5,
      number=10, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='per_query', full_name='mdg.engine.proto.StatsReport.per_query', index=6,
      number=14, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='legacy_per_query_implicit_operation_name', full_name='mdg.engine.proto.StatsReport.legacy_per_query_implicit_operation_name', index=7,
      number=12, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='mdg.engine.proto.StatsReport.type', index=8,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_STATSREPORT_PERQUERYENTRY, _STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7579,
  serialized_end=8266,
)


_FULLTRACESREPORT_TRACESPERQUERYENTRY = _descriptor.Descriptor(
  name='TracesPerQueryEntry',
  full_name='mdg.engine.proto.FullTracesReport.TracesPerQueryEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='mdg.engine.proto.FullTracesReport.TracesPerQueryEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='mdg.engine.proto.FullTracesReport.TracesPerQueryEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8419,
  serialized_end=8498,
)

_FULLTRACESREPORT = _descriptor.Descriptor(
  name='FullTracesReport',
  full_name='mdg.engine.proto.FullTracesReport',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='mdg.engine.proto.FullTracesReport.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='traces_per_query', full_name='mdg.engine.proto.FullTracesReport.traces_per_query', index=1,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_FULLTRACESREPORT_TRACESPERQUERYENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8269,
  serialized_end=8498,
)


_TRACES = _descriptor.Descriptor(
  name='Traces',
  full_name='mdg.engine.proto.Traces',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='trace', full_name='mdg.engine.proto.Traces.trace', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8500,
  serialized_end=8548,
)


_TRACEV1 = _descriptor.Descriptor(
  name='TraceV1',
  full_name='mdg.engine.proto.TraceV1',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='header', full_name='mdg.engine.proto.TraceV1.header', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='mdg.engine.proto.TraceV1.trace', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8550,
  serialized_end=8647,
)

_TRACE_CACHEPOLICY.fields_by_name['scope'].enum_type = _TRACE_CACHEPOLICY_SCOPE
_TRACE_CACHEPOLICY.containing_type = _TRACE
_TRACE_CACHEPOLICY_SCOPE.containing_type = _TRACE_CACHEPOLICY
_TRACE_DETAILS_VARIABLESJSONENTRY.containing_type = _TRACE_DETAILS
_TRACE_DETAILS_VARIABLESENTRY.containing_type = _TRACE_DETAILS
_TRACE_DETAILS.fields_by_name['variables_json'].message_type = _TRACE_DETAILS_VARIABLESJSONENTRY
_TRACE_DETAILS.fields_by_name['variables'].message_type = _TRACE_DETAILS_VARIABLESENTRY
_TRACE_DETAILS.containing_type = _TRACE
_TRACE_ERROR.fields_by_name['location'].message_type = _TRACE_LOCATION
_TRACE_ERROR.containing_type = _TRACE
_TRACE_HTTP_VALUES.containing_type = _TRACE_HTTP
_TRACE_HTTP_REQUESTHEADERSENTRY.fields_by_name['value'].message_type = _TRACE_HTTP_VALUES
_TRACE_HTTP_REQUESTHEADERSENTRY.containing_type = _TRACE_HTTP
_TRACE_HTTP_RESPONSEHEADERSENTRY.fields_by_name['value'].message_type = _TRACE_HTTP_VALUES
_TRACE_HTTP_RESPONSEHEADERSENTRY.containing_type = _TRACE_HTTP
_TRACE_HTTP.fields_by_name['method'].enum_type = _TRACE_HTTP_METHOD
_TRACE_HTTP.fields_by_name['request_headers'].message_type = _TRACE_HTTP_REQUESTHEADERSENTRY
_TRACE_HTTP.fields_by_name['response_headers'].message_type = _TRACE_HTTP_RESPONSEHEADERSENTRY
_TRACE_HTTP.containing_type = _TRACE
_TRACE_HTTP_METHOD.containing_type = _TRACE_HTTP
_TRACE_LOCATION.containing_type = _TRACE
_TRACE_NODE.fields_by_name['cache_policy'].message_type = _TRACE_CACHEPOLICY
_TRACE_NODE.fields_by_name['error'].message_type = _TRACE_ERROR
_TRACE_NODE.fields_by_name['child'].message_type = _TRACE_NODE
_TRACE_NODE.containing_type = _TRACE
_TRACE_NODE.oneofs_by_name['id'].fields.append(
  _TRACE_NODE.fields_by_name['response_name'])
_TRACE_NODE.fields_by_name['response_name'].containing_oneof = _TRACE_NODE.oneofs_by_name['id']
_TRACE_NODE.oneofs_by_name['id'].fields.append(
  _TRACE_NODE.fields_by_name['index'])
_TRACE_NODE.fields_by_name['index'].containing_oneof = _TRACE_NODE.oneofs_by_name['id']
_TRACE_QUERYPLANNODE_SEQUENCENODE.fields_by_name['nodes'].message_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_SEQUENCENODE.containing_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_PARALLELNODE.fields_by_name['nodes'].message_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_PARALLELNODE.containing_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_FETCHNODE.fields_by_name['trace'].message_type = _TRACE
_TRACE_QUERYPLANNODE_FETCHNODE.fields_by_name['sent_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACE_QUERYPLANNODE_FETCHNODE.fields_by_name['received_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACE_QUERYPLANNODE_FETCHNODE.containing_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_FLATTENNODE.fields_by_name['response_path'].message_type = _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT
_TRACE_QUERYPLANNODE_FLATTENNODE.fields_by_name['node'].message_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_FLATTENNODE.containing_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.containing_type = _TRACE_QUERYPLANNODE
_TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.oneofs_by_name['id'].fields.append(
  _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.fields_by_name['field_name'])
_TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.fields_by_name['field_name'].containing_oneof = _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.oneofs_by_name['id']
_TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.oneofs_by_name['id'].fields.append(
  _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.fields_by_name['index'])
_TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.fields_by_name['index'].containing_oneof = _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT.oneofs_by_name['id']
_TRACE_QUERYPLANNODE.fields_by_name['sequence'].message_type = _TRACE_QUERYPLANNODE_SEQUENCENODE
_TRACE_QUERYPLANNODE.fields_by_name['parallel'].message_type = _TRACE_QUERYPLANNODE_PARALLELNODE
_TRACE_QUERYPLANNODE.fields_by_name['fetch'].message_type = _TRACE_QUERYPLANNODE_FETCHNODE
_TRACE_QUERYPLANNODE.fields_by_name['flatten'].message_type = _TRACE_QUERYPLANNODE_FLATTENNODE
_TRACE_QUERYPLANNODE.containing_type = _TRACE
_TRACE_QUERYPLANNODE.oneofs_by_name['node'].fields.append(
  _TRACE_QUERYPLANNODE.fields_by_name['sequence'])
_TRACE_QUERYPLANNODE.fields_by_name['sequence'].containing_oneof = _TRACE_QUERYPLANNODE.oneofs_by_name['node']
_TRACE_QUERYPLANNODE.oneofs_by_name['node'].fields.append(
  _TRACE_QUERYPLANNODE.fields_by_name['parallel'])
_TRACE_QUERYPLANNODE.fields_by_name['parallel'].containing_oneof = _TRACE_QUERYPLANNODE.oneofs_by_name['node']
_TRACE_QUERYPLANNODE.oneofs_by_name['node'].fields.append(
  _TRACE_QUERYPLANNODE.fields_by_name['fetch'])
_TRACE_QUERYPLANNODE.fields_by_name['fetch'].containing_oneof = _TRACE_QUERYPLANNODE.oneofs_by_name['node']
_TRACE_QUERYPLANNODE.oneofs_by_name['node'].fields.append(
  _TRACE_QUERYPLANNODE.fields_by_name['flatten'])
_TRACE_QUERYPLANNODE.fields_by_name['flatten'].containing_oneof = _TRACE_QUERYPLANNODE.oneofs_by_name['node']
_TRACE.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACE.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACE.fields_by_name['root'].message_type = _TRACE_NODE
_TRACE.fields_by_name['details'].message_type = _TRACE_DETAILS
_TRACE.fields_by_name['http'].message_type = _TRACE_HTTP
_TRACE.fields_by_name['cache_policy'].message_type = _TRACE_CACHEPOLICY
_TRACE.fields_by_name['query_plan'].message_type = _TRACE_QUERYPLANNODE
_TRACE.fields_by_name['origin_reported_start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRACE.fields_by_name['origin_reported_end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_PATHERRORSTATS_CHILDRENENTRY.fields_by_name['value'].message_type = _PATHERRORSTATS
_PATHERRORSTATS_CHILDRENENTRY.containing_type = _PATHERRORSTATS
_PATHERRORSTATS.fields_by_name['children'].message_type = _PATHERRORSTATS_CHILDRENENTRY
_CLIENTNAMESTATS_REQUESTSCOUNTPERVERSIONENTRY.containing_type = _CLIENTNAMESTATS
_CLIENTNAMESTATS_CACHEHITSPERVERSIONENTRY.containing_type = _CLIENTNAMESTATS
_CLIENTNAMESTATS_PERSISTEDQUERYHITSPERVERSIONENTRY.containing_type = _CLIENTNAMESTATS
_CLIENTNAMESTATS_PERSISTEDQUERYMISSESPERVERSIONENTRY.containing_type = _CLIENTNAMESTATS
_CLIENTNAMESTATS_REGISTEREDOPERATIONCOUNTPERVERSIONENTRY.containing_type = _CLIENTNAMESTATS
_CLIENTNAMESTATS_FORBIDDENOPERATIONCOUNTPERVERSIONENTRY.containing_type = _CLIENTNAMESTATS
_CLIENTNAMESTATS.fields_by_name['requests_count_per_version'].message_type = _CLIENTNAMESTATS_REQUESTSCOUNTPERVERSIONENTRY
_CLIENTNAMESTATS.fields_by_name['cache_hits_per_version'].message_type = _CLIENTNAMESTATS_CACHEHITSPERVERSIONENTRY
_CLIENTNAMESTATS.fields_by_name['persisted_query_hits_per_version'].message_type = _CLIENTNAMESTATS_PERSISTEDQUERYHITSPERVERSIONENTRY
_CLIENTNAMESTATS.fields_by_name['persisted_query_misses_per_version'].message_type = _CLIENTNAMESTATS_PERSISTEDQUERYMISSESPERVERSIONENTRY
_CLIENTNAMESTATS.fields_by_name['registered_operation_count_per_version'].message_type = _CLIENTNAMESTATS_REGISTEREDOPERATIONCOUNTPERVERSIONENTRY
_CLIENTNAMESTATS.fields_by_name['forbidden_operation_count_per_version'].message_type = _CLIENTNAMESTATS_FORBIDDENOPERATIONCOUNTPERVERSIONENTRY
_CLIENTNAMESTATS.fields_by_name['root_error_stats'].message_type = _PATHERRORSTATS
_QUERYLATENCYSTATS.fields_by_name['root_error_stats'].message_type = _PATHERRORSTATS
_CONTEXTUALIZEDQUERYLATENCYSTATS.fields_by_name['query_latency_stats'].message_type = _QUERYLATENCYSTATS
_CONTEXTUALIZEDQUERYLATENCYSTATS.fields_by_name['context'].message_type = _STATSCONTEXT
_CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY.fields_by_name['value'].message_type = _TYPESTAT
_CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY.containing_type = _CONTEXTUALIZEDTYPESTATS
_CONTEXTUALIZEDTYPESTATS.fields_by_name['context'].message_type = _STATSCONTEXT
_CONTEXTUALIZEDTYPESTATS.fields_by_name['per_type_stat'].message_type = _CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY
_TYPESTAT_PERFIELDSTATENTRY.fields_by_name['value'].message_type = _FIELDSTAT
_TYPESTAT_PERFIELDSTATENTRY.containing_type = _TYPESTAT
_TYPESTAT.fields_by_name['field'].message_type = _FIELDSTAT
_TYPESTAT.fields_by_name['per_field_stat'].message_type = _TYPESTAT_PERFIELDSTATENTRY
_QUERYSTATS_PERCLIENTNAMEENTRY.fields_by_name['value'].message_type = _CLIENTNAMESTATS
_QUERYSTATS_PERCLIENTNAMEENTRY.containing_type = _QUERYSTATS
_QUERYSTATS_PERTYPESTATENTRY.fields_by_name['value'].message_type = _TYPESTAT
_QUERYSTATS_PERTYPESTATENTRY.containing_type = _QUERYSTATS
_QUERYSTATS.fields_by_name['per_client_name'].message_type = _QUERYSTATS_PERCLIENTNAMEENTRY
_QUERYSTATS.fields_by_name['query_stats_with_context'].message_type = _CONTEXTUALIZEDQUERYLATENCYSTATS
_QUERYSTATS.fields_by_name['per_type'].message_type = _TYPESTAT
_QUERYSTATS.fields_by_name['per_type_stat'].message_type = _QUERYSTATS_PERTYPESTATENTRY
_QUERYSTATS.fields_by_name['type_stats_with_context'].message_type = _CONTEXTUALIZEDTYPESTATS
_TRACESREPORT.fields_by_name['header'].message_type = _REPORTHEADER
_TRACESREPORT.fields_by_name['trace'].message_type = _TRACE
_TYPE.fields_by_name['field'].message_type = _FIELD
_STATSREPORT_PERQUERYENTRY.fields_by_name['value'].message_type = _QUERYSTATS
_STATSREPORT_PERQUERYENTRY.containing_type = _STATSREPORT
_STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY.fields_by_name['value'].message_type = _QUERYSTATS
_STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY.containing_type = _STATSREPORT
_STATSREPORT.fields_by_name['header'].message_type = _REPORTHEADER
_STATSREPORT.fields_by_name['mem_stats'].message_type = _MEMSTATS
_STATSREPORT.fields_by_name['time_stats'].message_type = _TIMESTATS
_STATSREPORT.fields_by_name['start_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATSREPORT.fields_by_name['end_time'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_STATSREPORT.fields_by_name['per_query'].message_type = _STATSREPORT_PERQUERYENTRY
_STATSREPORT.fields_by_name['legacy_per_query_implicit_operation_name'].message_type = _STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY
_STATSREPORT.fields_by_name['type'].message_type = _TYPE
_FULLTRACESREPORT_TRACESPERQUERYENTRY.fields_by_name['value'].message_type = _TRACES
_FULLTRACESREPORT_TRACESPERQUERYENTRY.containing_type = _FULLTRACESREPORT
_FULLTRACESREPORT.fields_by_name['header'].message_type = _REPORTHEADER
_FULLTRACESREPORT.fields_by_name['traces_per_query'].message_type = _FULLTRACESREPORT_TRACESPERQUERYENTRY
_TRACES.fields_by_name['trace'].message_type = _TRACE
_TRACEV1.fields_by_name['header'].message_type = _REPORTHEADER
_TRACEV1.fields_by_name['trace'].message_type = _TRACE
DESCRIPTOR.message_types_by_name['Trace'] = _TRACE
DESCRIPTOR.message_types_by_name['ReportHeader'] = _REPORTHEADER
DESCRIPTOR.message_types_by_name['PathErrorStats'] = _PATHERRORSTATS
DESCRIPTOR.message_types_by_name['ClientNameStats'] = _CLIENTNAMESTATS
DESCRIPTOR.message_types_by_name['QueryLatencyStats'] = _QUERYLATENCYSTATS
DESCRIPTOR.message_types_by_name['StatsContext'] = _STATSCONTEXT
DESCRIPTOR.message_types_by_name['ContextualizedQueryLatencyStats'] = _CONTEXTUALIZEDQUERYLATENCYSTATS
DESCRIPTOR.message_types_by_name['ContextualizedTypeStats'] = _CONTEXTUALIZEDTYPESTATS
DESCRIPTOR.message_types_by_name['FieldStat'] = _FIELDSTAT
DESCRIPTOR.message_types_by_name['TypeStat'] = _TYPESTAT
DESCRIPTOR.message_types_by_name['QueryStats'] = _QUERYSTATS
DESCRIPTOR.message_types_by_name['TracesReport'] = _TRACESREPORT
DESCRIPTOR.message_types_by_name['Field'] = _FIELD
DESCRIPTOR.message_types_by_name['Type'] = _TYPE
DESCRIPTOR.message_types_by_name['MemStats'] = _MEMSTATS
DESCRIPTOR.message_types_by_name['TimeStats'] = _TIMESTATS
DESCRIPTOR.message_types_by_name['StatsReport'] = _STATSREPORT
DESCRIPTOR.message_types_by_name['FullTracesReport'] = _FULLTRACESREPORT
DESCRIPTOR.message_types_by_name['Traces'] = _TRACES
DESCRIPTOR.message_types_by_name['TraceV1'] = _TRACEV1
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Trace = _reflection.GeneratedProtocolMessageType('Trace', (_message.Message,), dict(

  CachePolicy = _reflection.GeneratedProtocolMessageType('CachePolicy', (_message.Message,), dict(
    DESCRIPTOR = _TRACE_CACHEPOLICY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.CachePolicy)
    ))
  ,

  Details = _reflection.GeneratedProtocolMessageType('Details', (_message.Message,), dict(

    VariablesJsonEntry = _reflection.GeneratedProtocolMessageType('VariablesJsonEntry', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_DETAILS_VARIABLESJSONENTRY,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.Details.VariablesJsonEntry)
      ))
    ,

    VariablesEntry = _reflection.GeneratedProtocolMessageType('VariablesEntry', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_DETAILS_VARIABLESENTRY,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.Details.VariablesEntry)
      ))
    ,
    DESCRIPTOR = _TRACE_DETAILS,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.Details)
    ))
  ,

  Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
    DESCRIPTOR = _TRACE_ERROR,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.Error)
    ))
  ,

  HTTP = _reflection.GeneratedProtocolMessageType('HTTP', (_message.Message,), dict(

    Values = _reflection.GeneratedProtocolMessageType('Values', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_HTTP_VALUES,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.HTTP.Values)
      ))
    ,

    RequestHeadersEntry = _reflection.GeneratedProtocolMessageType('RequestHeadersEntry', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_HTTP_REQUESTHEADERSENTRY,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.HTTP.RequestHeadersEntry)
      ))
    ,

    ResponseHeadersEntry = _reflection.GeneratedProtocolMessageType('ResponseHeadersEntry', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_HTTP_RESPONSEHEADERSENTRY,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.HTTP.ResponseHeadersEntry)
      ))
    ,
    DESCRIPTOR = _TRACE_HTTP,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.HTTP)
    ))
  ,

  Location = _reflection.GeneratedProtocolMessageType('Location', (_message.Message,), dict(
    DESCRIPTOR = _TRACE_LOCATION,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.Location)
    ))
  ,

  Node = _reflection.GeneratedProtocolMessageType('Node', (_message.Message,), dict(
    DESCRIPTOR = _TRACE_NODE,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.Node)
    ))
  ,

  QueryPlanNode = _reflection.GeneratedProtocolMessageType('QueryPlanNode', (_message.Message,), dict(

    SequenceNode = _reflection.GeneratedProtocolMessageType('SequenceNode', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_QUERYPLANNODE_SEQUENCENODE,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.QueryPlanNode.SequenceNode)
      ))
    ,

    ParallelNode = _reflection.GeneratedProtocolMessageType('ParallelNode', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_QUERYPLANNODE_PARALLELNODE,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.QueryPlanNode.ParallelNode)
      ))
    ,

    FetchNode = _reflection.GeneratedProtocolMessageType('FetchNode', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_QUERYPLANNODE_FETCHNODE,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.QueryPlanNode.FetchNode)
      ))
    ,

    FlattenNode = _reflection.GeneratedProtocolMessageType('FlattenNode', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_QUERYPLANNODE_FLATTENNODE,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.QueryPlanNode.FlattenNode)
      ))
    ,

    ResponsePathElement = _reflection.GeneratedProtocolMessageType('ResponsePathElement', (_message.Message,), dict(
      DESCRIPTOR = _TRACE_QUERYPLANNODE_RESPONSEPATHELEMENT,
      __module__ = 'reports_pb2'
      # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.QueryPlanNode.ResponsePathElement)
      ))
    ,
    DESCRIPTOR = _TRACE_QUERYPLANNODE,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace.QueryPlanNode)
    ))
  ,
  DESCRIPTOR = _TRACE,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.Trace)
  ))
_sym_db.RegisterMessage(Trace)
_sym_db.RegisterMessage(Trace.CachePolicy)
_sym_db.RegisterMessage(Trace.Details)
_sym_db.RegisterMessage(Trace.Details.VariablesJsonEntry)
_sym_db.RegisterMessage(Trace.Details.VariablesEntry)
_sym_db.RegisterMessage(Trace.Error)
_sym_db.RegisterMessage(Trace.HTTP)
_sym_db.RegisterMessage(Trace.HTTP.Values)
_sym_db.RegisterMessage(Trace.HTTP.RequestHeadersEntry)
_sym_db.RegisterMessage(Trace.HTTP.ResponseHeadersEntry)
_sym_db.RegisterMessage(Trace.Location)
_sym_db.RegisterMessage(Trace.Node)
_sym_db.RegisterMessage(Trace.QueryPlanNode)
_sym_db.RegisterMessage(Trace.QueryPlanNode.SequenceNode)
_sym_db.RegisterMessage(Trace.QueryPlanNode.ParallelNode)
_sym_db.RegisterMessage(Trace.QueryPlanNode.FetchNode)
_sym_db.RegisterMessage(Trace.QueryPlanNode.FlattenNode)
_sym_db.RegisterMessage(Trace.QueryPlanNode.ResponsePathElement)

ReportHeader = _reflection.GeneratedProtocolMessageType('ReportHeader', (_message.Message,), dict(
  DESCRIPTOR = _REPORTHEADER,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.ReportHeader)
  ))
_sym_db.RegisterMessage(ReportHeader)

PathErrorStats = _reflection.GeneratedProtocolMessageType('PathErrorStats', (_message.Message,), dict(

  ChildrenEntry = _reflection.GeneratedProtocolMessageType('ChildrenEntry', (_message.Message,), dict(
    DESCRIPTOR = _PATHERRORSTATS_CHILDRENENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.PathErrorStats.ChildrenEntry)
    ))
  ,
  DESCRIPTOR = _PATHERRORSTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.PathErrorStats)
  ))
_sym_db.RegisterMessage(PathErrorStats)
_sym_db.RegisterMessage(PathErrorStats.ChildrenEntry)

ClientNameStats = _reflection.GeneratedProtocolMessageType('ClientNameStats', (_message.Message,), dict(

  RequestsCountPerVersionEntry = _reflection.GeneratedProtocolMessageType('RequestsCountPerVersionEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTNAMESTATS_REQUESTSCOUNTPERVERSIONENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats.RequestsCountPerVersionEntry)
    ))
  ,

  CacheHitsPerVersionEntry = _reflection.GeneratedProtocolMessageType('CacheHitsPerVersionEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTNAMESTATS_CACHEHITSPERVERSIONENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats.CacheHitsPerVersionEntry)
    ))
  ,

  PersistedQueryHitsPerVersionEntry = _reflection.GeneratedProtocolMessageType('PersistedQueryHitsPerVersionEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTNAMESTATS_PERSISTEDQUERYHITSPERVERSIONENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats.PersistedQueryHitsPerVersionEntry)
    ))
  ,

  PersistedQueryMissesPerVersionEntry = _reflection.GeneratedProtocolMessageType('PersistedQueryMissesPerVersionEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTNAMESTATS_PERSISTEDQUERYMISSESPERVERSIONENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats.PersistedQueryMissesPerVersionEntry)
    ))
  ,

  RegisteredOperationCountPerVersionEntry = _reflection.GeneratedProtocolMessageType('RegisteredOperationCountPerVersionEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTNAMESTATS_REGISTEREDOPERATIONCOUNTPERVERSIONENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats.RegisteredOperationCountPerVersionEntry)
    ))
  ,

  ForbiddenOperationCountPerVersionEntry = _reflection.GeneratedProtocolMessageType('ForbiddenOperationCountPerVersionEntry', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTNAMESTATS_FORBIDDENOPERATIONCOUNTPERVERSIONENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats.ForbiddenOperationCountPerVersionEntry)
    ))
  ,
  DESCRIPTOR = _CLIENTNAMESTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.ClientNameStats)
  ))
_sym_db.RegisterMessage(ClientNameStats)
_sym_db.RegisterMessage(ClientNameStats.RequestsCountPerVersionEntry)
_sym_db.RegisterMessage(ClientNameStats.CacheHitsPerVersionEntry)
_sym_db.RegisterMessage(ClientNameStats.PersistedQueryHitsPerVersionEntry)
_sym_db.RegisterMessage(ClientNameStats.PersistedQueryMissesPerVersionEntry)
_sym_db.RegisterMessage(ClientNameStats.RegisteredOperationCountPerVersionEntry)
_sym_db.RegisterMessage(ClientNameStats.ForbiddenOperationCountPerVersionEntry)

QueryLatencyStats = _reflection.GeneratedProtocolMessageType('QueryLatencyStats', (_message.Message,), dict(
  DESCRIPTOR = _QUERYLATENCYSTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.QueryLatencyStats)
  ))
_sym_db.RegisterMessage(QueryLatencyStats)

StatsContext = _reflection.GeneratedProtocolMessageType('StatsContext', (_message.Message,), dict(
  DESCRIPTOR = _STATSCONTEXT,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.StatsContext)
  ))
_sym_db.RegisterMessage(StatsContext)

ContextualizedQueryLatencyStats = _reflection.GeneratedProtocolMessageType('ContextualizedQueryLatencyStats', (_message.Message,), dict(
  DESCRIPTOR = _CONTEXTUALIZEDQUERYLATENCYSTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.ContextualizedQueryLatencyStats)
  ))
_sym_db.RegisterMessage(ContextualizedQueryLatencyStats)

ContextualizedTypeStats = _reflection.GeneratedProtocolMessageType('ContextualizedTypeStats', (_message.Message,), dict(

  PerTypeStatEntry = _reflection.GeneratedProtocolMessageType('PerTypeStatEntry', (_message.Message,), dict(
    DESCRIPTOR = _CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.ContextualizedTypeStats.PerTypeStatEntry)
    ))
  ,
  DESCRIPTOR = _CONTEXTUALIZEDTYPESTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.ContextualizedTypeStats)
  ))
_sym_db.RegisterMessage(ContextualizedTypeStats)
_sym_db.RegisterMessage(ContextualizedTypeStats.PerTypeStatEntry)

FieldStat = _reflection.GeneratedProtocolMessageType('FieldStat', (_message.Message,), dict(
  DESCRIPTOR = _FIELDSTAT,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.FieldStat)
  ))
_sym_db.RegisterMessage(FieldStat)

TypeStat = _reflection.GeneratedProtocolMessageType('TypeStat', (_message.Message,), dict(

  PerFieldStatEntry = _reflection.GeneratedProtocolMessageType('PerFieldStatEntry', (_message.Message,), dict(
    DESCRIPTOR = _TYPESTAT_PERFIELDSTATENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.TypeStat.PerFieldStatEntry)
    ))
  ,
  DESCRIPTOR = _TYPESTAT,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.TypeStat)
  ))
_sym_db.RegisterMessage(TypeStat)
_sym_db.RegisterMessage(TypeStat.PerFieldStatEntry)

QueryStats = _reflection.GeneratedProtocolMessageType('QueryStats', (_message.Message,), dict(

  PerClientNameEntry = _reflection.GeneratedProtocolMessageType('PerClientNameEntry', (_message.Message,), dict(
    DESCRIPTOR = _QUERYSTATS_PERCLIENTNAMEENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.QueryStats.PerClientNameEntry)
    ))
  ,

  PerTypeStatEntry = _reflection.GeneratedProtocolMessageType('PerTypeStatEntry', (_message.Message,), dict(
    DESCRIPTOR = _QUERYSTATS_PERTYPESTATENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.QueryStats.PerTypeStatEntry)
    ))
  ,
  DESCRIPTOR = _QUERYSTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.QueryStats)
  ))
_sym_db.RegisterMessage(QueryStats)
_sym_db.RegisterMessage(QueryStats.PerClientNameEntry)
_sym_db.RegisterMessage(QueryStats.PerTypeStatEntry)

TracesReport = _reflection.GeneratedProtocolMessageType('TracesReport', (_message.Message,), dict(
  DESCRIPTOR = _TRACESREPORT,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.TracesReport)
  ))
_sym_db.RegisterMessage(TracesReport)

Field = _reflection.GeneratedProtocolMessageType('Field', (_message.Message,), dict(
  DESCRIPTOR = _FIELD,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.Field)
  ))
_sym_db.RegisterMessage(Field)

Type = _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), dict(
  DESCRIPTOR = _TYPE,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.Type)
  ))
_sym_db.RegisterMessage(Type)

MemStats = _reflection.GeneratedProtocolMessageType('MemStats', (_message.Message,), dict(
  DESCRIPTOR = _MEMSTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.MemStats)
  ))
_sym_db.RegisterMessage(MemStats)

TimeStats = _reflection.GeneratedProtocolMessageType('TimeStats', (_message.Message,), dict(
  DESCRIPTOR = _TIMESTATS,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.TimeStats)
  ))
_sym_db.RegisterMessage(TimeStats)

StatsReport = _reflection.GeneratedProtocolMessageType('StatsReport', (_message.Message,), dict(

  PerQueryEntry = _reflection.GeneratedProtocolMessageType('PerQueryEntry', (_message.Message,), dict(
    DESCRIPTOR = _STATSREPORT_PERQUERYENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.StatsReport.PerQueryEntry)
    ))
  ,

  LegacyPerQueryImplicitOperationNameEntry = _reflection.GeneratedProtocolMessageType('LegacyPerQueryImplicitOperationNameEntry', (_message.Message,), dict(
    DESCRIPTOR = _STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.StatsReport.LegacyPerQueryImplicitOperationNameEntry)
    ))
  ,
  DESCRIPTOR = _STATSREPORT,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.StatsReport)
  ))
_sym_db.RegisterMessage(StatsReport)
_sym_db.RegisterMessage(StatsReport.PerQueryEntry)
_sym_db.RegisterMessage(StatsReport.LegacyPerQueryImplicitOperationNameEntry)

FullTracesReport = _reflection.GeneratedProtocolMessageType('FullTracesReport', (_message.Message,), dict(

  TracesPerQueryEntry = _reflection.GeneratedProtocolMessageType('TracesPerQueryEntry', (_message.Message,), dict(
    DESCRIPTOR = _FULLTRACESREPORT_TRACESPERQUERYENTRY,
    __module__ = 'reports_pb2'
    # @@protoc_insertion_point(class_scope:mdg.engine.proto.FullTracesReport.TracesPerQueryEntry)
    ))
  ,
  DESCRIPTOR = _FULLTRACESREPORT,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.FullTracesReport)
  ))
_sym_db.RegisterMessage(FullTracesReport)
_sym_db.RegisterMessage(FullTracesReport.TracesPerQueryEntry)

Traces = _reflection.GeneratedProtocolMessageType('Traces', (_message.Message,), dict(
  DESCRIPTOR = _TRACES,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.Traces)
  ))
_sym_db.RegisterMessage(Traces)

TraceV1 = _reflection.GeneratedProtocolMessageType('TraceV1', (_message.Message,), dict(
  DESCRIPTOR = _TRACEV1,
  __module__ = 'reports_pb2'
  # @@protoc_insertion_point(class_scope:mdg.engine.proto.TraceV1)
  ))
_sym_db.RegisterMessage(TraceV1)


_TRACE_DETAILS_VARIABLESJSONENTRY._options = None
_TRACE_DETAILS_VARIABLESENTRY._options = None
_TRACE_HTTP_REQUESTHEADERSENTRY._options = None
_TRACE_HTTP_RESPONSEHEADERSENTRY._options = None
_PATHERRORSTATS_CHILDRENENTRY._options = None
_CLIENTNAMESTATS_REQUESTSCOUNTPERVERSIONENTRY._options = None
_CLIENTNAMESTATS_CACHEHITSPERVERSIONENTRY._options = None
_CLIENTNAMESTATS_PERSISTEDQUERYHITSPERVERSIONENTRY._options = None
_CLIENTNAMESTATS_PERSISTEDQUERYMISSESPERVERSIONENTRY._options = None
_CLIENTNAMESTATS_REGISTEREDOPERATIONCOUNTPERVERSIONENTRY._options = None
_CLIENTNAMESTATS_FORBIDDENOPERATIONCOUNTPERVERSIONENTRY._options = None
_CONTEXTUALIZEDTYPESTATS_PERTYPESTATENTRY._options = None
_TYPESTAT_PERFIELDSTATENTRY._options = None
_QUERYSTATS_PERCLIENTNAMEENTRY._options = None
_QUERYSTATS_PERTYPESTATENTRY._options = None
_STATSREPORT_PERQUERYENTRY._options = None
_STATSREPORT_LEGACYPERQUERYIMPLICITOPERATIONNAMEENTRY._options = None
_FULLTRACESREPORT_TRACESPERQUERYENTRY._options = None
# @@protoc_insertion_point(module_scope)
